<?php
/*  
Copyright 2009  Randy Hunt  (email : bbqiguana@gmail.com)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

Plugin Name: TweetPost
Description: Integrates your wordpress blog with your twitter account, automatically posting to twitter when a new post is made on your blog
Version: 0.2
Author: Randy Hunt
*/

//require_once( "twitter-func.php" );
require_once('twitter.lib.php');

function tweetpost_savepost ($post_id) {

	$post = get_post($post_id);

	//ignore revisions
	if ($post->post_type == 'revision') return;

	//ignore non-published data and password protected data
	if ($post->post_status != 'publish' || $post->post_password != '' ) return;
	
	$title = $post->post_title;
	$link = get_permalink($post_id);

	$bitly = tweetpost_bitly($link);
	if (!$bitly) return;
	
	//get settings
	$twitter_username = get_option('tweetpost_twitter_user');
	$twitter_password = get_option('tweetpost_twitter_pass');
	$twitterer = get_usermeta($post->post_author, 'twitter');
	if ($twitterer) {
		$twitterer = '@'.$twitterer;
	} else {
		$user=get_userdata($post->post_author);
		$twitterer = $user->user_nicename;
	}

	//create Tweet...
	$twitter = new Twitter($twitter_username, $twitter_password);
	$tweet = 'New post by ' . $twitterer . ' : ';
	$limit = 140 - (strlen($tweet) + strlen($bitly) + 1);
	if (strlen($title) > $limit) {
		$title = substr($title, 0, $limit - 3) . '...';
	}

	$tweet = $tweet . $title . ' ' . $bitly;
	$twitter->updateStatus($tweet);
}

function tweetpost_bitly ($url) {
	$user = get_option('tweetpost_bitly_user');
	//$pass = get_option('tweetpost_bitly_pass');
	$apik = get_option('tweetpost_bitly_apikey');
	
	$endpoint = 'http://api.bit.ly/shorten?version=2.0.1&history=1&format=xml&login='.$user.'&apiKey='.$apik.'&longUrl='.$url;
	$xml = file_get_contents($endpoint);

	preg_match('/<errorcode>([^<]+)<\/errorcode>/i', $xml, $matches);
	if($matches && $matches[1]!='0') return false;
	
	preg_match('/<shorturl>([^<]+)<\/shorturl>/i', $xml, $matches);
	
	if($matches && $matches[1]) return $matches[1];
	else return false;
}

function tweetpost_showuser ($user) {
	?>
	<h3>Extra profile information</h3>
	<table class="form-table">
	<tr><th><label for="twitter">Twitter</label></th><td>
	<input type="text" name="twitter" id="twitter" value="<?php echo esc_attr( get_the_author_meta('twitter', $user->ID ) ) ?>" class="regular-text" /><br />
	<span class="description">Please enter your Twitter username.</span>
	</td></tr></table>
	<?php
}

function tweetpost_edituser ($user_id) {
	if ( !current_user_can('edit_user', $user_id) )
		return false;

	/* Copy and paste this line for additional fields. Make sure to change 'twitter' to the field ID. */
	update_usermeta($user_id, 'twitter', $_POST['twitter'] );
}

function tweetpost_updtwitter ($userid, $twitterid) {
	update_usermeta ($userid, 'twitter', $twitterid);
}

function tweetpost_init () {

	register_setting('tweetpost', 'twitter_username');
	register_setting('tweetpost', 'twitter_password');
	register_setting('tweetpost', 'bitly_username');
	register_setting('tweetpost', 'bitly_password');
	register_setting('tweetpost', 'bitly_apikey');
}

function tweetpost_install () {
	$tweetpost_username = get_option('tweetpost_username');
	$tweetpost_password = get_option('tweetpost_password');

	if (!$tweetpost_username) update_option('tweetpost_username', 'username');
	if (!$tweetpost_password) update_option('tweetpost_password', 'password');
}

function tweetpost_menu () {
	if ( function_exists('add_options_page') ) {
		add_options_page('TweetPost', 'TweetPost', 8, 'tweetpost', 'tweetpost_options');
	}
}

function tweetpost_options () {
	echo "<div class=\"wrap\">";
	echo "<h2>Tweetpost</h2>";
	if ( ($_POST['action']=='update') ) {
		//check_admin_referer('externimg_update-action');
		update_option('tweetpost_twitter_user', $_POST['twitter_username']);
		update_option('tweetpost_twitter_pass', $_POST['twitter_password']);
		update_option('tweetpost_bitly_user',   $_POST['bitly_username']  );
		update_option('tweetpost_bitly_pass',   $_POST['bitly_password']  );
		update_option('tweetpost_bitly_apikey', $_POST['bitly_apikey']    );
		echo '<div id="message" class="updated fade" style="background-color:rgb(255,251,204);"><p>Settings updated.</p></div>';
	}
	echo '<form name="tweetpost-options" method="post" action="">';
	settings_fields('tweetpost');

	?>
	<big>Twitter</big>
	<table class="form-table">
	<tr><th><label for="twitter_username">Twitter Username</label></th>
	<td><input type="text" size="15" name="twitter_username" id="twitter_username" value="<?php echo esc_attr(get_option('tweetpost_twitter_user')) ?>" class="regular-text" /><br />
		<span class="description">Please enter the Twitter username for your site.</span>
	</td></tr>
	<tr><th><label for="twitter_password">Twitter Password</label></th>
	<td><input type="text" size="15" name="twitter_password" id="twitter_password" value="<?php echo esc_attr(get_option('tweetpost_twitter_pass'))  ?>" class="regular-text" /><br />
		<span class="description">Please enter the Twitter password for your site.</span>
	</td></tr>
	<tr><td>&nbsp;</td><td><span id="tweetpost_twitterresult" style="padding:2px"></span></td></tr>
	</table>
	
	<big>Bit.ly</big>
	<table class="form-table">
	<tr><th><label for="bitly_username">Bit.ly Username</label></th>
	<td><input type="text" size="15" name="bitly_username" id="bitly_username" value="<?php echo esc_attr(get_option('tweetpost_bitly_user')) ?>" class="regular-text" /><br />
		<span class="description">Please enter the Bit.ly username for your site.</span>
	</td></tr>
	<tr><th><label for="bitly_apikey">Bit.ly API key</label></th>
	<td><input type="text" size="20" name="bitly_apikey" id="bitly_apikey" value="<?php echo esc_attr(get_option('tweetpost_bitly_apikey')) ?>" class="regular-text" /><br />
		<span class="description">Please enter the Bit.ly API key for your site.</span>
	</td></tr>
	<tr><td>&nbsp;</td><td><span id="tweetpost_bitlyresult" style="padding:2px"></span></td></tr>
	</table>

	<div class="submit">
		<input type="hidden" name="externimg_update" value="action" />
		<input type="submit" name="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
	</div>
	</form>
	<div class="wrap">
		<big>Donate</big>
		<p>If you like this plugin consider donating a small amount to the author using PayPal to support further plugin development.</p>
		<div align="center"><form name="_xclick" action="https://www.paypal.com/us/cgi-bin/webscr" method="post"><input type="hidden" name="cmd" value="_xclick"><input type="hidden" name="business" value="bbqiguana@gmail.com"><input type="hidden" name="item_name" value="Donations for TweetPost plugin"><input type="hidden" name="currency_code" value="USD"><input type="image" src="http://www.paypal.com/en_US/i/btn/btn_donate_LG.gif" border="0" name="submit" alt="Make payments with PayPal - it's fast, free and secure!"></form></div>
		<p>If you think donating money is somehow impersonal you could also choose items from my <a href="http://www.amazon.com/registry/wishlist/18LMHOMRM49P8/ref=cm_wl_act_vv">Amazon.com wishlist</a>.</p>
	</div>

	</div>
	<?php
}

function tweetpost_admin_update () {
	//
}

if ( is_admin() ) { // admin actions
	add_action('admin_menu', 'tweetpost_menu');
	add_action('admin_init', 'tweetpost_init');

	$tweetpostdir = trailingslashit(get_bloginfo('wpurl')).PLUGINDIR.'/'.dirname(plugin_basename(__FILE__));
	wp_enqueue_script("jquery");
	wp_enqueue_script("tweetpost", $tweetpostdir.'/tweetpost.js', array('jquery'));
}

register_activation_hook(__FILE__, 'tweetpost_install');

add_action('show_user_profile', 'tweetpost_showuser');
add_action('edit_user_profile', 'tweetpost_showuser');
add_action('personal_options_update', 'tweetpost_edituser');
add_action('edit_user_profile_update', 'tweetpost_edituser');
//add_action('save_post', 'tweetpost_savepost');
add_action('new_to_publish', 'tweetpost_savepost');
add_action('draft_to_publish', 'tweetpost_savepost');
add_action('pending_to_publish', 'tweetpost_savepost');
add_action('future_to_publish', 'tweetpost_savepost');

?>
